# -*- coding: utf-8 -*-
'''
Created on Sun Dec  8 14:49:19 2024

@author: mstep
'''

# See: https://stackoverflow.com/questions/55619783/tkinter-i-created-a-custom-scrollable-frame-class-is-it-possible-for-it-to-au

import tkinter as tk

class ScrolledFrame(tk.Frame):
    def __init__(self, frame, *args, **kwargs):
        tk.Frame.__init__(self, frame, *args, **kwargs)

        # Make row 0 and column 0 expand.
        self.columnconfigure(0, weight=1)
        self.rowconfigure(0, weight=1)

        # Scrollbars.
        self.v_scroll = tk.Scrollbar(self, orient=tk.VERTICAL)
        self.v_scroll.grid(row=0, column=1, sticky=tk.NSEW)

        self.h_scroll = tk.Scrollbar(self, orient=tk.HORIZONTAL)
        self.h_scroll.grid(row=1, column=0, sticky=tk.NSEW)

        # Canvas.
        self.canvas = tk.Canvas(self,
            xscrollcommand=self.h_scroll.set,
            yscrollcommand=self.v_scroll.set)
        self.canvas.grid(row=0, column=0, sticky=tk.NSEW)

        # Configure the canvas.
        self.v_scroll.config(command=self.canvas.yview)
        self.h_scroll.config(command=self.canvas.xview)

        # Frame.
        self.frame = tk.Frame(self.canvas)
        self.frame_window = self.canvas.create_window(0, 0,
            window=self.frame, anchor=tk.NW)


    def configure_frame(self):
        self.frame.update_idletasks()
        width = self.frame.winfo_reqwidth()
        height = self.frame.winfo_reqheight()
        self.canvas.config(scrollregion=(0, 0, width, height))

        # Bind the mouse wheel to scroll the canvas.
        for child in widget_and_descendants(self.canvas):
            child.bind('<MouseWheel>', self.wheel_scroll)
            #child.bind('<Button-4>', self.wheel_scroll)
            #child.bind('<Button-5>', self.wheel_scroll)

    def wheel_scroll(self, event):
        ''' Scroll the canvas.'''
        # This is the Windows version.
        # Divide event.delta by some number to slow scrolling. Some people
        # recommend dividing by 120 for Windows, but I left it alone to make
        # it scroll about the same speed when the mouse is over the scrollbar.
        print(event.delta)
        units = -int(event.delta / 30)
        self.canvas.yview_scroll(units, 'units')

def widget_and_descendants(parent):
    '''Return this widget and all of its descendants.'''
    results = [parent]
    for child in parent.winfo_children():
        results += widget_and_descendants(child)
    return results

#%%
import tkinter as tk
from PIL import Image, ImageTk

class ScrolledWindowApp:
    def __init__(self):
        # Make the main interface.
        self.window = tk.Tk()
        self.window.title('scrolled_wheel_frame')
        self.window.protocol('WM_DELETE_WINDOW', self.kill_callback)
        self.window.geometry('500x400')

        # Make a ScrolledFrame.
        scrolled_frame = ScrolledFrame(self.window)
        scrolled_frame.pack(side=tk.TOP, fill=tk.BOTH, expand=True)

        # Save the frame so we can put things in it.
        my_frame = scrolled_frame.frame

        ###############################
        # Put some things in the frame.
        self.tk_images = []
        for i in range(0, 10, 2):
            label = tk.Label(my_frame, text='A pretty long label in a big font',
                height=5, padx=20, bg='light yellow')
            label.config(font = ('Arial', 30))
            label.grid(row=i, column=0)
    
            path = 'robot_working.jpg'
            image = Image.open(path)
            tk_image = ImageTk.PhotoImage(image)
            image_label = tk.Label(my_frame, image=tk_image)
            image_label.grid(column=1, row=i)
            self.tk_images.append(tk_image)

        # Configure the frame. (Do this after adding all contained widgets.)
        scrolled_frame.configure_frame()

        # Display the window.
        self.window.mainloop()

    def kill_callback(self):
        self.window.destroy()

#%%

ScrolledWindowApp()
print('Done')
